Stan Math Library: stan/math/prim/scal/fun/inv_sqrt.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

inv_sqrt.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_PRIM_SCAL_FUN_INV_SQRT_HPP
2 #define STAN_MATH_PRIM_SCAL_FUN_INV_SQRT_HPP
3
4 #include <boost/math/tools/promotion.hpp>
5
6 namespace stan {
7 namespace math {
8
9 template <typename T>
10 inline
11 typename boost::math::tools::promote_args<T>::type
12 inv_sqrt(const T x) {
13 using std::sqrt;
14
15 return 1.0 / sqrt(x);
16 }
17
18 }
19 }
20
21 #endif
stan::math::inv_sqrt
fvar< T > inv_sqrt(const fvar< T > &x)
Definition: inv_sqrt.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8

[ Stan Home Page ] © 2011–2016, Stan Development Team.